# GradGen

Code generation for cost gradient

### Installation instructions

To build this project locally:

- Create a virtual environment: `virtualenv -p python3 venv`
- Activate the virtual environment. On Linux/MacOS, run `source venv/bin/activate`
- Install the project: `pip install .`

The folder `playground` can be used during the design phase of the project to try out different things, but it should be removed for release.


